# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/target_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/vpc/v1/target_group.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xbb\x01\n\x0bTargetGroup\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1.TargetGroupSpecR\x04spec\x12\x38\n\x06status\x18\x03 \x01(\x0b\x32 .nebius.vpc.v1.TargetGroupStatusR\x06status\"B\n\x0fTargetGroupSpec\x12/\n\x07targets\x18\x01 \x03(\x0b\x32\x15.nebius.vpc.v1.TargetR\x07targets\"f\n\x06Target\x12K\n\x10\x63ompute_instance\x18\x01 \x01(\x0b\x32\x1e.nebius.vpc.v1.ComputeInstanceH\x00R\x0f\x63omputeInstanceB\x0f\n\x06target\x12\x05\xbaH\x02\x08\x01\"e\n\x0f\x43omputeInstance\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12:\n\x16network_interface_name\x18\x02 \x01(\tB\x04\xbaJ\x01\x07R\x14networkInterfaceName\"\x85\x01\n\x11TargetGroupStatus\x12*\n\x11load_balancer_ids\x18\x01 \x03(\tR\x0floadBalancerIds\x12\x44\n\x0ftarget_statuses\x18\x02 \x03(\x0b\x32\x1b.nebius.vpc.v1.TargetStatusR\x0etargetStatuses\"\xdd\x01\n\x0cTargetStatus\x12.\n\x13\x63ompute_instance_id\x18\x01 \x01(\tR\x11\x63omputeInstanceId\x12J\n\x0ctarget_state\x18\x02 \x01(\x0e\x32\'.nebius.vpc.v1.TargetStatus.TargetStateR\x0btargetState\"Q\n\x0bTargetState\x12\x1c\n\x18TARGET_STATE_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x42W\n\x14\x61i.nebius.pub.vpc.v1B\x10TargetGroupProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.target_group_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\020TargetGroupProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _TARGET.oneofs_by_name['target']._options = None
  _TARGET.oneofs_by_name['target']._serialized_options = b'\272H\002\010\001'
  _COMPUTEINSTANCE.fields_by_name['id']._options = None
  _COMPUTEINSTANCE.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _COMPUTEINSTANCE.fields_by_name['network_interface_name']._options = None
  _COMPUTEINSTANCE.fields_by_name['network_interface_name']._serialized_options = b'\272J\001\007'
  _globals['_TARGETGROUP']._serialized_start=140
  _globals['_TARGETGROUP']._serialized_end=327
  _globals['_TARGETGROUPSPEC']._serialized_start=329
  _globals['_TARGETGROUPSPEC']._serialized_end=395
  _globals['_TARGET']._serialized_start=397
  _globals['_TARGET']._serialized_end=499
  _globals['_COMPUTEINSTANCE']._serialized_start=501
  _globals['_COMPUTEINSTANCE']._serialized_end=602
  _globals['_TARGETGROUPSTATUS']._serialized_start=605
  _globals['_TARGETGROUPSTATUS']._serialized_end=738
  _globals['_TARGETSTATUS']._serialized_start=741
  _globals['_TARGETSTATUS']._serialized_end=962
  _globals['_TARGETSTATUS_TARGETSTATE']._serialized_start=881
  _globals['_TARGETSTATUS_TARGETSTATE']._serialized_end=962
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from nebius.api.nebius.storage.v1 import base_pb2 as _base_pb2
from nebius.api.nebius.storage.v1 import bucket_counters_pb2 as _bucket_counters_pb2
from nebius.api.nebius.storage.v1 import lifecycle_pb2 as _lifecycle_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Bucket(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: BucketSpec
    status: BucketStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[BucketSpec, _Mapping]] = ..., status: _Optional[_Union[BucketStatus, _Mapping]] = ...) -> None: ...

class BucketSpec(_message.Message):
    __slots__ = ["versioning_policy", "max_size_bytes", "lifecycle_configuration", "default_storage_class", "override_storage_class", "force_storage_class"]
    VERSIONING_POLICY_FIELD_NUMBER: _ClassVar[int]
    MAX_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    LIFECYCLE_CONFIGURATION_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_STORAGE_CLASS_FIELD_NUMBER: _ClassVar[int]
    OVERRIDE_STORAGE_CLASS_FIELD_NUMBER: _ClassVar[int]
    FORCE_STORAGE_CLASS_FIELD_NUMBER: _ClassVar[int]
    versioning_policy: _base_pb2.VersioningPolicy
    max_size_bytes: int
    lifecycle_configuration: _lifecycle_pb2.LifecycleConfiguration
    default_storage_class: _base_pb2.StorageClass
    override_storage_class: _base_pb2.StorageClass
    force_storage_class: bool
    def __init__(self, versioning_policy: _Optional[_Union[_base_pb2.VersioningPolicy, str]] = ..., max_size_bytes: _Optional[int] = ..., lifecycle_configuration: _Optional[_Union[_lifecycle_pb2.LifecycleConfiguration, _Mapping]] = ..., default_storage_class: _Optional[_Union[_base_pb2.StorageClass, str]] = ..., override_storage_class: _Optional[_Union[_base_pb2.StorageClass, str]] = ..., force_storage_class: bool = ...) -> None: ...

class BucketStatus(_message.Message):
    __slots__ = ["counters", "state", "suspension_state", "deleted_at", "purge_at", "domain_name", "region"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[BucketStatus.State]
        CREATING: _ClassVar[BucketStatus.State]
        ACTIVE: _ClassVar[BucketStatus.State]
        UPDATING: _ClassVar[BucketStatus.State]
        SCHEDULED_FOR_DELETION: _ClassVar[BucketStatus.State]
    STATE_UNSPECIFIED: BucketStatus.State
    CREATING: BucketStatus.State
    ACTIVE: BucketStatus.State
    UPDATING: BucketStatus.State
    SCHEDULED_FOR_DELETION: BucketStatus.State
    class SuspensionState(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        SUSPENSION_STATE_UNSPECIFIED: _ClassVar[BucketStatus.SuspensionState]
        NOT_SUSPENDED: _ClassVar[BucketStatus.SuspensionState]
        SUSPENDED: _ClassVar[BucketStatus.SuspensionState]
    SUSPENSION_STATE_UNSPECIFIED: BucketStatus.SuspensionState
    NOT_SUSPENDED: BucketStatus.SuspensionState
    SUSPENDED: BucketStatus.SuspensionState
    COUNTERS_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    SUSPENSION_STATE_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    PURGE_AT_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_NAME_FIELD_NUMBER: _ClassVar[int]
    REGION_FIELD_NUMBER: _ClassVar[int]
    counters: _containers.RepeatedCompositeFieldContainer[_bucket_counters_pb2.BucketCounters]
    state: BucketStatus.State
    suspension_state: BucketStatus.SuspensionState
    deleted_at: _timestamp_pb2.Timestamp
    purge_at: _timestamp_pb2.Timestamp
    domain_name: str
    region: str
    def __init__(self, counters: _Optional[_Iterable[_Union[_bucket_counters_pb2.BucketCounters, _Mapping]]] = ..., state: _Optional[_Union[BucketStatus.State, str]] = ..., suspension_state: _Optional[_Union[BucketStatus.SuspensionState, str]] = ..., deleted_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., purge_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., domain_name: _Optional[str] = ..., region: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/authentication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.audit.v2 import access_token_pb2 as nebius_dot_audit_dot_v2_dot_access__token__pb2
from nebius.api.nebius.audit.v2 import authentication_type_pb2 as nebius_dot_audit_dot_v2_dot_authentication__type__pb2
from nebius.api.nebius.audit.v2 import federation_pb2 as nebius_dot_audit_dot_v2_dot_federation__pb2
from nebius.api.nebius.audit.v2 import static_key_pb2 as nebius_dot_audit_dot_v2_dot_static__key__pb2
from nebius.api.nebius.audit.v2 import subject_pb2 as nebius_dot_audit_dot_v2_dot_subject__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/audit/v2/authentication.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\"nebius/audit/v2/access_token.proto\x1a)nebius/audit/v2/authentication_type.proto\x1a nebius/audit/v2/federation.proto\x1a nebius/audit/v2/static_key.proto\x1a\x1dnebius/audit/v2/subject.proto\"\xb0\x03\n\x0e\x41uthentication\x12,\n\rauthenticated\x18\x01 \x01(\x08\x42\x06\xbaH\x03\xc8\x01\x01R\rauthenticated\x12\x32\n\x07subject\x18\x02 \x01(\x0b\x32\x18.nebius.audit.v2.SubjectR\x07subject\x12;\n\nfederation\x18\x03 \x01(\x0b\x32\x1b.nebius.audit.v2.FederationR\nfederation\x12T\n\x13\x61uthentication_type\x18\x04 \x01(\x0e\x32#.nebius.audit.v2.AuthenticationTypeR\x12\x61uthenticationType\x12I\n\x10token_credential\x18\n \x01(\x0b\x32\x1c.nebius.audit.v2.AccessTokenH\x00R\x0ftokenCredential\x12P\n\x15static_key_credential\x18\x0b \x01(\x0b\x32\x1a.nebius.audit.v2.StaticKeyH\x00R\x13staticKeyCredentialB\x0c\n\ncredentialB^\n\x16\x61i.nebius.pub.audit.v2B\x13\x41uthenticationProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\023AuthenticationProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _AUTHENTICATION.fields_by_name['authenticated']._options = None
  _AUTHENTICATION.fields_by_name['authenticated']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AUTHENTICATION']._serialized_start=265
  _globals['_AUTHENTICATION']._serialized_end=697
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/v1alpha1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n nebius/msp/v1alpha1/common.proto\x12\x13nebius.msp.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\"$\n\nGetRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"S\n\x10GetByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\'\n\rDeleteRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"&\n\x0cStartRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"%\n\x0bStopRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"w\n\x0bListRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12$\n\tpage_size\x18\x02 \x01(\x03\x42\x07\xbaH\x04\"\x02(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"P\n\x14UpdateVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12 \n\x07version\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07versionB^\n\x1a\x61i.nebius.pub.msp.v1alpha1B\x0b\x43ommonProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.v1alpha1.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.msp.v1alpha1B\013CommonProtoP\001Z1github.com/nebius/gosdk/proto/nebius/msp/v1alpha1'
  _GETREQUEST.fields_by_name['id']._options = None
  _GETREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _DELETEREQUEST.fields_by_name['id']._options = None
  _DELETEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _STARTREQUEST.fields_by_name['id']._options = None
  _STARTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _STOPREQUEST.fields_by_name['id']._options = None
  _STOPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTREQUEST.fields_by_name['parent_id']._options = None
  _LISTREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTREQUEST.fields_by_name['page_size']._options = None
  _LISTREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\004\"\002(\000'
  _UPDATEVERSIONREQUEST.fields_by_name['id']._options = None
  _UPDATEVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEVERSIONREQUEST.fields_by_name['version']._options = None
  _UPDATEVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETREQUEST']._serialized_start=86
  _globals['_GETREQUEST']._serialized_end=122
  _globals['_GETBYNAMEREQUEST']._serialized_start=124
  _globals['_GETBYNAMEREQUEST']._serialized_end=207
  _globals['_DELETEREQUEST']._serialized_start=209
  _globals['_DELETEREQUEST']._serialized_end=248
  _globals['_STARTREQUEST']._serialized_start=250
  _globals['_STARTREQUEST']._serialized_end=288
  _globals['_STOPREQUEST']._serialized_start=290
  _globals['_STOPREQUEST']._serialized_end=327
  _globals['_LISTREQUEST']._serialized_start=329
  _globals['_LISTREQUEST']._serialized_end=448
  _globals['_UPDATEVERSIONREQUEST']._serialized_start=450
  _globals['_UPDATEVERSIONREQUEST']._serialized_end=530
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mysterybox/v1/secret_version_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.mysterybox.v1 import secret_version_pb2 as nebius_dot_mysterybox_dot_v1_dot_secret__version__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1nebius/mysterybox/v1/secret_version_service.proto\x12\x14nebius.mysterybox.v1\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1b\x62uf/validate/validate.proto\x1a)nebius/mysterybox/v1/secret_version.proto\x1a\x18nebius/annotations.proto\"\x99\x01\n\x1a\x43reateSecretVersionRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.mysterybox.v1.SecretVersionSpecR\x04spec\"p\n\x17GetSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12=\n\x1bshow_scheduled_for_deletion\x18\x02 \x01(\x08R\x18showScheduledForDeletion\"\xca\x01\n\x19ListSecretVersionsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12*\n\tpage_size\x18\x02 \x01(\x03\x42\r\xbaH\n\xd8\x01\x01\"\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12=\n\x1bshow_scheduled_for_deletion\x18\x04 \x01(\x08R\x18showScheduledForDeletion\"\x7f\n\x1aListSecretVersionsResponse\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x39\n\x05items\x18\x03 \x03(\x0b\x32#.nebius.mysterybox.v1.SecretVersionR\x05items\"4\n\x1a\x44\x65leteSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"6\n\x1cUndeleteSecretVersionRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xfe\x03\n\x14SecretVersionService\x12W\n\x06\x43reate\x12\x30.nebius.mysterybox.v1.CreateSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x12Y\n\x03Get\x12-.nebius.mysterybox.v1.GetSecretVersionRequest\x1a#.nebius.mysterybox.v1.SecretVersion\x12i\n\x04List\x12/.nebius.mysterybox.v1.ListSecretVersionsRequest\x1a\x30.nebius.mysterybox.v1.ListSecretVersionsResponse\x12W\n\x06\x44\x65lete\x12\x30.nebius.mysterybox.v1.DeleteSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x12[\n\x08Undelete\x12\x32.nebius.mysterybox.v1.UndeleteSecretVersionRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x11\xbaJ\x0e\x63pl.mysteryboxBn\n\x1b\x61i.nebius.pub.mysterybox.v1B\x19SecretVersionServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mysterybox.v1.secret_version_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mysterybox.v1B\031SecretVersionServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mysterybox/v1'
  _GETSECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _GETSECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSECRETVERSIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTSECRETVERSIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTSECRETVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTSECRETVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\n\330\001\001\"\005\030\350\007(\000'
  _DELETESECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _DELETESECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UNDELETESECRETVERSIONREQUEST.fields_by_name['id']._options = None
  _UNDELETESECRETVERSIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _SECRETVERSIONSERVICE._options = None
  _SECRETVERSIONSERVICE._serialized_options = b'\272J\016cpl.mysterybox'
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_start=241
  _globals['_CREATESECRETVERSIONREQUEST']._serialized_end=394
  _globals['_GETSECRETVERSIONREQUEST']._serialized_start=396
  _globals['_GETSECRETVERSIONREQUEST']._serialized_end=508
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_start=511
  _globals['_LISTSECRETVERSIONSREQUEST']._serialized_end=713
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_start=715
  _globals['_LISTSECRETVERSIONSRESPONSE']._serialized_end=842
  _globals['_DELETESECRETVERSIONREQUEST']._serialized_start=844
  _globals['_DELETESECRETVERSIONREQUEST']._serialized_end=896
  _globals['_UNDELETESECRETVERSIONREQUEST']._serialized_start=898
  _globals['_UNDELETESECRETVERSIONREQUEST']._serialized_end=952
  _globals['_SECRETVERSIONSERVICE']._serialized_start=955
  _globals['_SECRETVERSIONSERVICE']._serialized_end=1465
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/registry/v1/artifact_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.registry.v1 import artifact_pb2 as nebius_dot_registry_dot_v1_dot_artifact__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/registry/v1/artifact_service.proto\x12\x12nebius.registry.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a nebius/common/v1/operation.proto\x1a!nebius/registry/v1/artifact.proto\",\n\x12GetArtifactRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x87\x01\n\x14ListArtifactsRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"s\n\x15ListArtifactsResponse\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32\x1c.nebius.registry.v1.ArtifactR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"/\n\x15\x44\x65leteArtifactRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\x9a\x02\n\x0f\x41rtifactService\x12K\n\x03Get\x12&.nebius.registry.v1.GetArtifactRequest\x1a\x1c.nebius.registry.v1.Artifact\x12[\n\x04List\x12(.nebius.registry.v1.ListArtifactsRequest\x1a).nebius.registry.v1.ListArtifactsResponse\x12P\n\x06\x44\x65lete\x12).nebius.registry.v1.DeleteArtifactRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x0b\xbaJ\x08registryBe\n\x19\x61i.nebius.pub.registry.v1B\x14\x41rtifactServiceProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/registry/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.registry.v1.artifact_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.registry.v1B\024ArtifactServiceProtoP\001Z0github.com/nebius/gosdk/proto/nebius/registry/v1'
  _GETARTIFACTREQUEST.fields_by_name['id']._options = None
  _GETARTIFACTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEARTIFACTREQUEST.fields_by_name['id']._options = None
  _DELETEARTIFACTREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ARTIFACTSERVICE._options = None
  _ARTIFACTSERVICE._serialized_options = b'\272J\010registry'
  _globals['_GETARTIFACTREQUEST']._serialized_start=189
  _globals['_GETARTIFACTREQUEST']._serialized_end=233
  _globals['_LISTARTIFACTSREQUEST']._serialized_start=236
  _globals['_LISTARTIFACTSREQUEST']._serialized_end=371
  _globals['_LISTARTIFACTSRESPONSE']._serialized_start=373
  _globals['_LISTARTIFACTSRESPONSE']._serialized_end=488
  _globals['_DELETEARTIFACTREQUEST']._serialized_start=490
  _globals['_DELETEARTIFACTREQUEST']._serialized_end=537
  _globals['_ARTIFACTSERVICE']._serialized_start=540
  _globals['_ARTIFACTSERVICE']._serialized_end=822
# @@protoc_insertion_point(module_scope)



from nebius.api.nebius.mysterybox.v1 import payload_pb2 as _payload_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetPayloadRequest(_message.Message):
    __slots__ = ["secret_id", "version_id"]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    secret_id: str
    version_id: str
    def __init__(self, secret_id: _Optional[str] = ..., version_id: _Optional[str] = ...) -> None: ...

class GetPayloadByKeyRequest(_message.Message):
    __slots__ = ["secret_id", "version_id", "key"]
    SECRET_ID_FIELD_NUMBER: _ClassVar[int]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    secret_id: str
    version_id: str
    key: str
    def __init__(self, secret_id: _Optional[str] = ..., version_id: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class SecretPayload(_message.Message):
    __slots__ = ["version_id", "data"]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    version_id: str
    data: _containers.RepeatedCompositeFieldContainer[_payload_pb2.Payload]
    def __init__(self, version_id: _Optional[str] = ..., data: _Optional[_Iterable[_Union[_payload_pb2.Payload, _Mapping]]] = ...) -> None: ...

class SecretPayloadEntry(_message.Message):
    __slots__ = ["version_id", "data"]
    VERSION_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    version_id: str
    data: _payload_pb2.Payload
    def __init__(self, version_id: _Optional[str] = ..., data: _Optional[_Union[_payload_pb2.Payload, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/registry/v1/artifact.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!nebius/registry/v1/artifact.proto\x12\x12nebius.registry.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb9\x04\n\x08\x41rtifact\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x1d\n\nmedia_type\x18\x03 \x01(\tR\tmediaType\x12\x16\n\x06\x64igest\x18\x04 \x01(\tR\x06\x64igest\x12\x12\n\x04size\x18\x05 \x01(\x03R\x04size\x12;\n\x06status\x18\x06 \x01(\x0e\x32#.nebius.registry.v1.Artifact.StatusR\x06status\x12\x35\n\x04type\x18\x07 \x01(\x0e\x32!.nebius.registry.v1.Artifact.TypeR\x04type\x12\x39\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x39\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tupdatedAt\x12\x12\n\x04tags\x18\n \x03(\tR\x04tags\":\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\"\x83\x01\n\x04Type\x12\x08\n\x04\x42LOB\x10\x00\x12\x0c\n\x08MANIFEST\x10\x01\x12\x0f\n\x0b\x44\x45\x42_PACKAGE\x10\x02\x12\x11\n\rMANIFEST_LIST\x10\x03\x12\x11\n\rRELEASE_INDEX\x10\x04\x12\x11\n\rPACKAGE_INDEX\x10\x05\x12\x19\n\x15GZIPPED_PACKAGE_INDEX\x10\x06\x42^\n\x19\x61i.nebius.pub.registry.v1B\rArtifactProtoP\x01Z0github.com/nebius/gosdk/proto/nebius/registry/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.registry.v1.artifact_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031ai.nebius.pub.registry.v1B\rArtifactProtoP\001Z0github.com/nebius/gosdk/proto/nebius/registry/v1'
  _globals['_ARTIFACT']._serialized_start=91
  _globals['_ARTIFACT']._serialized_end=660
  _globals['_ARTIFACT_STATUS']._serialized_start=468
  _globals['_ARTIFACT_STATUS']._serialized_end=526
  _globals['_ARTIFACT_TYPE']._serialized_start=529
  _globals['_ARTIFACT_TYPE']._serialized_end=660
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/storage/v1alpha1/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/storage/v1alpha1/transfer.proto\x12\x17nebius.storage.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\"\xdc\x01\n\x08Transfer\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x41\n\x04spec\x18\x02 \x01(\x0b\x32%.nebius.storage.v1alpha1.TransferSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32\'.nebius.storage.v1alpha1.TransferStatusB\x04\xbaJ\x01\x05R\x06status\"\xf2\x11\n\x0cTransferSpec\x12R\n\x06source\x18\x01 \x01(\x0b\x32\x32.nebius.storage.v1alpha1.TransferSpec.SourceBucketB\x06\xbaH\x03\xc8\x01\x01R\x06source\x12\x61\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x37.nebius.storage.v1alpha1.TransferSpec.DestinationBucketB\x06\xbaH\x03\xc8\x01\x01R\x0b\x64\x65stination\x12|\n\x13\x61\x66ter_one_iteration\x18\x03 \x01(\x0b\x32\x44.nebius.storage.v1alpha1.TransferSpec.StopConditionAfterOneIterationB\x04\xbaJ\x01\x06H\x00R\x11\x61\x66terOneIteration\x12\x83\x01\n\x18\x61\x66ter_n_empty_iterations\x18\x04 \x01(\x0b\x32H.nebius.storage.v1alpha1.TransferSpec.StopConditionAfterNEmptyIterationsH\x00R\x15\x61\x66terNEmptyIterations\x12_\n\x08infinite\x18\x05 \x01(\x0b\x32;.nebius.storage.v1alpha1.TransferSpec.StopConditionInfiniteB\x04\xbaJ\x01\x06H\x00R\x08infinite\x12\x61\n\x18inter_iteration_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0c\xbaH\x05\xaa\x01\x02\x32\x00\xbaJ\x01\x07R\x16interIterationInterval\x12n\n\x12overwrite_strategy\x18\x07 \x01(\x0e\x32\x37.nebius.storage.v1alpha1.TransferSpec.OverwriteStrategyB\x06\xbaH\x03\xc8\x01\x01R\x11overwriteStrategy\x1a\xb4\x02\n\x0cSourceBucket\x12&\n\x08\x65ndpoint\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x08\x65ndpoint\x12+\n\x0b\x62ucket_name\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\nbucketName\x12\"\n\x06region\x18\x03 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x06region\x12_\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32\x37.nebius.storage.v1alpha1.TransferSpec.BucketCredentialsB\x04\xbaJ\x01\x04R\x0b\x63redentials\x12J\n\x08limiters\x18\x05 \x01(\x0b\x32..nebius.storage.v1alpha1.TransferSpec.LimitersR\x08limiters\x1a\xa1\x01\n\x11\x44\x65stinationBucket\x12+\n\x0b\x62ucket_name\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\nbucketName\x12_\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x37.nebius.storage.v1alpha1.TransferSpec.BucketCredentialsB\x04\xbaJ\x01\x04R\x0b\x63redentials\x1a\x80\x05\n\x11\x42ucketCredentials\x12r\n\tanonymous\x18\x01 \x01(\x0b\x32L.nebius.storage.v1alpha1.TransferSpec.BucketCredentials.CredentialsAnonymousB\x04\xbaJ\x01\x06H\x00R\tanonymous\x12m\n\naccess_key\x18\x02 \x01(\x0b\x32L.nebius.storage.v1alpha1.TransferSpec.BucketCredentials.CredentialsAccessKeyH\x00R\taccessKey\x12r\n\x10\x61zure_access_key\x18\x03 \x01(\x0b\x32\x46.nebius.storage.v1alpha1.TransferSpec.BucketCredentials.AzureAccessKeyH\x00R\x0e\x61zureAccessKey\x1a\x16\n\x14\x43redentialsAnonymous\x1a|\n\x14\x43redentialsAccessKey\x12-\n\raccess_key_id\x18\x01 \x01(\tB\t\xbaH\x03\xc8\x01\x01\xc0J\x01R\x0b\x61\x63\x63\x65ssKeyId\x12\x35\n\x11secret_access_key\x18\x02 \x01(\tB\t\xbaH\x03\xc8\x01\x01\xc0J\x01R\x0fsecretAccessKey\x1ah\n\x0e\x41zureAccessKey\x12,\n\x0c\x61\x63\x63ount_name\x18\x02 \x01(\tB\t\xbaH\x03\xc8\x01\x01\xc0J\x01R\x0b\x61\x63\x63ountName\x12(\n\naccess_key\x18\x01 \x01(\tB\t\xbaH\x03\xc8\x01\x01\xc0J\x01R\taccessKeyB\x14\n\x0b\x63redentials\x12\x05\xbaH\x02\x08\x01\x1aw\n\x08Limiters\x12;\n\x1a\x62\x61ndwidth_bytes_per_second\x18\x01 \x01(\x04R\x17\x62\x61ndwidthBytesPerSecond\x12.\n\x13requests_per_second\x18\x02 \x01(\x04R\x11requestsPerSecond\x1a \n\x1eStopConditionAfterOneIteration\x1aj\n\"StopConditionAfterNEmptyIterations\x12\x44\n\x1a\x65mpty_iterations_threshold\x18\x01 \x01(\rB\x06\xbaH\x03\xc8\x01\x01R\x18\x65mptyIterationsThreshold\x1a\x17\n\x15StopConditionInfinite\"\\\n\x11OverwriteStrategy\x12\"\n\x1eOVERWRITE_STRATEGY_UNSPECIFIED\x10\x00\x12\t\n\x05NEVER\x10\x01\x12\x0c\n\x08IF_NEWER\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\x42\x17\n\x0estop_condition\x12\x05\xbaH\x02\x08\x01\"\xd9\x03\n\x0eTransferStatus\x12\x43\n\x05state\x18\x01 \x01(\x0e\x32-.nebius.storage.v1alpha1.TransferStatus.StateR\x05state\x12\x14\n\x05\x65rror\x18\x02 \x01(\tR\x05\x65rror\x12\x62\n\x10suspension_state\x18\x03 \x01(\x0e\x32\x37.nebius.storage.v1alpha1.TransferStatus.SuspensionStateR\x0fsuspensionState\x12Q\n\x0elast_iteration\x18\x04 \x01(\x0b\x32*.nebius.storage.v1alpha1.TransferIterationR\rlastIteration\"^\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08STOPPING\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x12\x0b\n\x07\x46\x41ILING\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\"U\n\x0fSuspensionState\x12 \n\x1cSUSPENSION_STATE_UNSPECIFIED\x10\x00\x12\x11\n\rNOT_SUSPENDED\x10\x01\x12\r\n\tSUSPENDED\x10\x02\"\xf7\x04\n\x11TransferIteration\x12\'\n\x0fsequence_number\x18\x01 \x01(\x03R\x0esequenceNumber\x12\x46\n\x05state\x18\x02 \x01(\x0e\x32\x30.nebius.storage.v1alpha1.TransferIteration.StateR\x05state\x12\x14\n\x05\x65rror\x18\x03 \x01(\tR\x05\x65rror\x12\x39\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x38\n\x18objects_discovered_count\x18\x06 \x01(\x03R\x16objectsDiscoveredCount\x12\x34\n\x16objects_migrated_count\x18\x07 \x01(\x03R\x14objectsMigratedCount\x12\x32\n\x15objects_skipped_count\x18\x08 \x01(\x03R\x13objectsSkippedCount\x12\x32\n\x15objects_migrated_size\x18\t \x01(\x03R\x13objectsMigratedSize\x12\x38\n\x18\x61verage_throughput_bytes\x18\n \x01(\x03R\x16\x61verageThroughputBytes\"W\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\r\n\tCOMPLETED\x10\x02\x12\x0b\n\x07STOPPED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42h\n\x1e\x61i.nebius.pub.storage.v1alpha1B\rTransferProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/storage/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.storage.v1alpha1.transfer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.storage.v1alpha1B\rTransferProtoP\001Z5github.com/nebius/gosdk/proto/nebius/storage/v1alpha1'
  _TRANSFER.fields_by_name['metadata']._options = None
  _TRANSFER.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _TRANSFER.fields_by_name['spec']._options = None
  _TRANSFER.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _TRANSFER.fields_by_name['status']._options = None
  _TRANSFER.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['endpoint']._options = None
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['endpoint']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['bucket_name']._options = None
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['bucket_name']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['region']._options = None
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['region']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['credentials']._options = None
  _TRANSFERSPEC_SOURCEBUCKET.fields_by_name['credentials']._serialized_options = b'\272J\001\004'
  _TRANSFERSPEC_DESTINATIONBUCKET.fields_by_name['bucket_name']._options = None
  _TRANSFERSPEC_DESTINATIONBUCKET.fields_by_name['bucket_name']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _TRANSFERSPEC_DESTINATIONBUCKET.fields_by_name['credentials']._options = None
  _TRANSFERSPEC_DESTINATIONBUCKET.fields_by_name['credentials']._serialized_options = b'\272J\001\004'
  _TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY.fields_by_name['access_key_id']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY.fields_by_name['access_key_id']._serialized_options = b'\272H\003\310\001\001\300J\001'
  _TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY.fields_by_name['secret_access_key']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY.fields_by_name['secret_access_key']._serialized_options = b'\272H\003\310\001\001\300J\001'
  _TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY.fields_by_name['account_name']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY.fields_by_name['account_name']._serialized_options = b'\272H\003\310\001\001\300J\001'
  _TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY.fields_by_name['access_key']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY.fields_by_name['access_key']._serialized_options = b'\272H\003\310\001\001\300J\001'
  _TRANSFERSPEC_BUCKETCREDENTIALS.oneofs_by_name['credentials']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS.oneofs_by_name['credentials']._serialized_options = b'\272H\002\010\001'
  _TRANSFERSPEC_BUCKETCREDENTIALS.fields_by_name['anonymous']._options = None
  _TRANSFERSPEC_BUCKETCREDENTIALS.fields_by_name['anonymous']._serialized_options = b'\272J\001\006'
  _TRANSFERSPEC_STOPCONDITIONAFTERNEMPTYITERATIONS.fields_by_name['empty_iterations_threshold']._options = None
  _TRANSFERSPEC_STOPCONDITIONAFTERNEMPTYITERATIONS.fields_by_name['empty_iterations_threshold']._serialized_options = b'\272H\003\310\001\001'
  _TRANSFERSPEC.oneofs_by_name['stop_condition']._options = None
  _TRANSFERSPEC.oneofs_by_name['stop_condition']._serialized_options = b'\272H\002\010\001'
  _TRANSFERSPEC.fields_by_name['source']._options = None
  _TRANSFERSPEC.fields_by_name['source']._serialized_options = b'\272H\003\310\001\001'
  _TRANSFERSPEC.fields_by_name['destination']._options = None
  _TRANSFERSPEC.fields_by_name['destination']._serialized_options = b'\272H\003\310\001\001'
  _TRANSFERSPEC.fields_by_name['after_one_iteration']._options = None
  _TRANSFERSPEC.fields_by_name['after_one_iteration']._serialized_options = b'\272J\001\006'
  _TRANSFERSPEC.fields_by_name['infinite']._options = None
  _TRANSFERSPEC.fields_by_name['infinite']._serialized_options = b'\272J\001\006'
  _TRANSFERSPEC.fields_by_name['inter_iteration_interval']._options = None
  _TRANSFERSPEC.fields_by_name['inter_iteration_interval']._serialized_options = b'\272H\005\252\001\0022\000\272J\001\007'
  _TRANSFERSPEC.fields_by_name['overwrite_strategy']._options = None
  _TRANSFERSPEC.fields_by_name['overwrite_strategy']._serialized_options = b'\272H\003\310\001\001'
  _globals['_TRANSFER']._serialized_start=221
  _globals['_TRANSFER']._serialized_end=441
  _globals['_TRANSFERSPEC']._serialized_start=444
  _globals['_TRANSFERSPEC']._serialized_end=2734
  _globals['_TRANSFERSPEC_SOURCEBUCKET']._serialized_start=1212
  _globals['_TRANSFERSPEC_SOURCEBUCKET']._serialized_end=1520
  _globals['_TRANSFERSPEC_DESTINATIONBUCKET']._serialized_start=1523
  _globals['_TRANSFERSPEC_DESTINATIONBUCKET']._serialized_end=1684
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS']._serialized_start=1687
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS']._serialized_end=2327
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSANONYMOUS']._serialized_start=2051
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSANONYMOUS']._serialized_end=2073
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY']._serialized_start=2075
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_CREDENTIALSACCESSKEY']._serialized_end=2199
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY']._serialized_start=2201
  _globals['_TRANSFERSPEC_BUCKETCREDENTIALS_AZUREACCESSKEY']._serialized_end=2305
  _globals['_TRANSFERSPEC_LIMITERS']._serialized_start=2329
  _globals['_TRANSFERSPEC_LIMITERS']._serialized_end=2448
  _globals['_TRANSFERSPEC_STOPCONDITIONAFTERONEITERATION']._serialized_start=2450
  _globals['_TRANSFERSPEC_STOPCONDITIONAFTERONEITERATION']._serialized_end=2482
  _globals['_TRANSFERSPEC_STOPCONDITIONAFTERNEMPTYITERATIONS']._serialized_start=2484
  _globals['_TRANSFERSPEC_STOPCONDITIONAFTERNEMPTYITERATIONS']._serialized_end=2590
  _globals['_TRANSFERSPEC_STOPCONDITIONINFINITE']._serialized_start=2592
  _globals['_TRANSFERSPEC_STOPCONDITIONINFINITE']._serialized_end=2615
  _globals['_TRANSFERSPEC_OVERWRITESTRATEGY']._serialized_start=2617
  _globals['_TRANSFERSPEC_OVERWRITESTRATEGY']._serialized_end=2709
  _globals['_TRANSFERSTATUS']._serialized_start=2737
  _globals['_TRANSFERSTATUS']._serialized_end=3210
  _globals['_TRANSFERSTATUS_STATE']._serialized_start=3029
  _globals['_TRANSFERSTATUS_STATE']._serialized_end=3123
  _globals['_TRANSFERSTATUS_SUSPENSIONSTATE']._serialized_start=3125
  _globals['_TRANSFERSTATUS_SUSPENSIONSTATE']._serialized_end=3210
  _globals['_TRANSFERITERATION']._serialized_start=3213
  _globals['_TRANSFERITERATION']._serialized_end=3844
  _globals['_TRANSFERITERATION_STATE']._serialized_start=3757
  _globals['_TRANSFERITERATION_STATE']._serialized_end=3844
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/group_membership.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.iam.v1 import service_account_pb2 as nebius_dot_iam_dot_v1_dot_service__account__pb2
from nebius.api.nebius.iam.v1 import tenant_user_account_pb2 as nebius_dot_iam_dot_v1_dot_tenant__user__account__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$nebius/iam/v1/group_membership.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a#nebius/iam/v1/service_account.proto\x1a\'nebius/iam/v1/tenant_user_account.proto\"\xa2\x02\n\x0fGroupMembership\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12>\n\x04spec\x18\x02 \x01(\x0b\x32\".nebius.iam.v1.GroupMembershipSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x42\n\x06status\x18\x03 \x01(\x0b\x32$.nebius.iam.v1.GroupMembershipStatusB\x04\xbaJ\x01\x05R\x06status\x12=\n\trevoke_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xbaJ\x01\x05R\x08revokeAt:\x04\xbaJ\x01\x02\"8\n\x13GroupMembershipSpec\x12!\n\tmember_id\x18\x01 \x01(\tB\x04\xbaJ\x01\x02R\x08memberId\"\xf2\x01\n\x15GroupMembershipStatus\x12\x65\n\x1atenant_user_account_status\x18\x01 \x01(\x0b\x32&.nebius.iam.v1.TenantUserAccountStatusH\x00R\x17tenantUserAccountStatus\x12[\n\x16service_account_status\x18\x02 \x01(\x0b\x32#.nebius.iam.v1.ServiceAccountStatusH\x00R\x14serviceAccountStatusB\x15\n\x13group_member_status\"\xc0\x01\n\x0fGroupMemberKind\x12\x37\n\x04kind\x18\x01 \x01(\x0e\x32#.nebius.iam.v1.GroupMemberKind.KindR\x04kind\"t\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12 \n\x1cORDINARY_TENANT_USER_ACCOUNT\x10\x01\x12\x1f\n\x1bINVITED_TENANT_USER_ACCOUNT\x10\x02\x12\x13\n\x0fSERVICE_ACCOUNT\x10\x03\"\xad\x03\n\x1dGroupMembershipWithAttributes\x12I\n\x10group_membership\x18\x01 \x01(\x0b\x32\x1e.nebius.iam.v1.GroupMembershipR\x0fgroupMembership\x12J\n\x11group_member_kind\x18\x0b \x01(\x0b\x32\x1e.nebius.iam.v1.GroupMemberKindR\x0fgroupMemberKind\x12H\n\x0fuser_attributes\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.UserAttributesH\x00R\x0euserAttributes\x12g\n\x1aservice_account_attributes\x18\x03 \x01(\x0b\x32\'.nebius.iam.v1.ServiceAccountAttributesH\x00R\x18serviceAccountAttributes\x12,\n\x05\x65rror\x18\x63 \x01(\x0b\x32\x14.nebius.iam.v1.ErrorH\x00R\x05\x65rrorB\x14\n\x12\x61ttributesOptionalB[\n\x14\x61i.nebius.pub.iam.v1B\x14GroupMembershipProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.group_membership_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\024GroupMembershipProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GROUPMEMBERSHIP.fields_by_name['metadata']._options = None
  _GROUPMEMBERSHIP.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _GROUPMEMBERSHIP.fields_by_name['spec']._options = None
  _GROUPMEMBERSHIP.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GROUPMEMBERSHIP.fields_by_name['status']._options = None
  _GROUPMEMBERSHIP.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _GROUPMEMBERSHIP.fields_by_name['revoke_at']._options = None
  _GROUPMEMBERSHIP.fields_by_name['revoke_at']._serialized_options = b'\272J\001\005'
  _GROUPMEMBERSHIP._options = None
  _GROUPMEMBERSHIP._serialized_options = b'\272J\001\002'
  _GROUPMEMBERSHIPSPEC.fields_by_name['member_id']._options = None
  _GROUPMEMBERSHIPSPEC.fields_by_name['member_id']._serialized_options = b'\272J\001\002'
  _globals['_GROUPMEMBERSHIP']._serialized_start=255
  _globals['_GROUPMEMBERSHIP']._serialized_end=545
  _globals['_GROUPMEMBERSHIPSPEC']._serialized_start=547
  _globals['_GROUPMEMBERSHIPSPEC']._serialized_end=603
  _globals['_GROUPMEMBERSHIPSTATUS']._serialized_start=606
  _globals['_GROUPMEMBERSHIPSTATUS']._serialized_end=848
  _globals['_GROUPMEMBERKIND']._serialized_start=851
  _globals['_GROUPMEMBERKIND']._serialized_end=1043
  _globals['_GROUPMEMBERKIND_KIND']._serialized_start=927
  _globals['_GROUPMEMBERKIND_KIND']._serialized_end=1043
  _globals['_GROUPMEMBERSHIPWITHATTRIBUTES']._serialized_start=1046
  _globals['_GROUPMEMBERSHIPWITHATTRIBUTES']._serialized_end=1475
# @@protoc_insertion_point(module_scope)



# type: ignore
import logging

from nebius.aio import request

request.DEFAULT_AUTH_TIMEOUT = 5.0


def test_get_instance_sync() -> None:
    from asyncio import (
        Event,
        new_event_loop,
        set_event_loop,
    )
    from concurrent.futures import Future
    from threading import Thread

    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel, NoCredentials
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            # Return an Instance object as expected by the client
            ret = disk_pb2.Disk()
            ret.metadata.id = request.id
            ret.metadata.name = "MockDisk"
            return ret

    def server_thread(port_future: Future[int], stop_event: Event) -> None:
        # Create a new event loop for the thread
        loop = new_event_loop()
        set_event_loop(loop)

        async def start_server():
            # Create the gRPC server
            srv = grpc.aio.server()
            add_DiskServiceServicer_to_server(MockInstanceService(), srv)

            # Bind to a random available port
            port = srv.add_insecure_port("[::]:0")
            port_future.set_result(port)  # Pass the port back to the main thread

            await srv.start()  # Start the server
            await stop_event.wait()
            await srv.stop(0)

        try:
            loop.run_until_complete(start_server())
        finally:
            loop.close()

    # Randomly assign an IPv6 address and port for the server

    # Future to share the port between threads
    port_future = Future[int]()
    stop_event = Event()

    # Start the server thread
    worker = Thread(
        target=server_thread,
        args=(
            port_future,
            stop_event,
        ),
        daemon=True,
    )
    worker.start()

    # Wait for the port to be set
    port = port_future.result()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address,
            options=[(INSECURE, True)],
            credentials=NoCredentials(),
        )
        from nebius.api.nebius.compute.v1 import DiskServiceClient, GetDiskRequest

        client = DiskServiceClient(channel)
        req = client.get(GetDiskRequest(id="foo-bar"))

        # Await response and metadata
        ret = req.wait()

        # Assertions to validate behavior
        assert ret.metadata.id == "foo-bar"
        assert ret.metadata.name == "MockDisk"

    finally:
        # Clean up
        if channel is not None:
            channel.sync_close()
        stop_event.set()


def test_get_instance_timeout_sync() -> None:
    from asyncio import (
        Event,
        new_event_loop,
        set_event_loop,
    )
    from concurrent.futures import Future
    from threading import Thread

    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel, NoCredentials
    from nebius.aio.service_error import RequestError
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""
            from asyncio import sleep

            await sleep(2)

            # Return an Instance object as expected by the client
            ret = disk_pb2.Disk()
            ret.metadata.id = request.id
            ret.metadata.name = "MockDisk"
            return ret

    def server_thread(port_future: Future[int], stop_event: Event) -> None:
        # Create a new event loop for the thread
        loop = new_event_loop()
        set_event_loop(loop)

        async def start_server():
            # Create the gRPC server
            srv = grpc.aio.server()
            add_DiskServiceServicer_to_server(MockInstanceService(), srv)

            # Bind to a random available port
            port = srv.add_insecure_port("[::]:0")
            port_future.set_result(port)  # Pass the port back to the main thread

            await srv.start()  # Start the server
            await stop_event.wait()
            await srv.stop(0)

        try:
            loop.run_until_complete(start_server())
        finally:
            loop.close()

    # Randomly assign an IPv6 address and port for the server

    # Future to share the port between threads
    port_future = Future[int]()
    stop_event = Event()

    # Start the server thread
    worker = Thread(
        target=server_thread,
        args=(
            port_future,
            stop_event,
        ),
        daemon=True,
    )
    worker.start()

    # Wait for the port to be set
    port = port_future.result()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address,
            options=[(INSECURE, True)],
            credentials=NoCredentials(),
        )
        from nebius.api.nebius.compute.v1 import DiskServiceClient, GetDiskRequest

        client = DiskServiceClient(channel)
        req = client.get(GetDiskRequest(id="foo-bar"), timeout=0.1)

        try:
            # Await response and metadata
            req.wait()
        except RequestError as e:
            assert str(e) == "Request error DEADLINE_EXCEEDED: Deadline Exceeded"
            assert e.status.code == grpc.StatusCode.DEADLINE_EXCEEDED

    finally:
        # Clean up
        if channel is not None:
            channel.sync_close()
        stop_event.set()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/authorization.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#nebius/audit/v2/authorization.proto\x12\x0fnebius.audit.v2\"/\n\rAuthorization\x12\x1e\n\nauthorized\x18\x01 \x01(\x08R\nauthorizedB]\n\x16\x61i.nebius.pub.audit.v2B\x12\x41uthorizationProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.authorization_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\022AuthorizationProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _globals['_AUTHORIZATION']._serialized_start=56
  _globals['_AUTHORIZATION']._serialized_end=103
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.billing.v1alpha1 import calculator_service_pb2 as nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2


class CalculatorServiceStub(object):
    """Calculator service for estimating resource costs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Estimate = channel.unary_unary(
                '/nebius.billing.v1alpha1.CalculatorService/Estimate',
                request_serializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateRequest.SerializeToString,
                response_deserializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateResponse.FromString,
                )
        self.EstimateBatch = channel.unary_unary(
                '/nebius.billing.v1alpha1.CalculatorService/EstimateBatch',
                request_serializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchRequest.SerializeToString,
                response_deserializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchResponse.FromString,
                )


class CalculatorServiceServicer(object):
    """Calculator service for estimating resource costs.
    """

    def Estimate(self, request, context):
        """Estimates prices for a single resource.
        Returns both hourly and monthly cost estimates for the specified resource configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateBatch(self, request, context):
        """Estimates prices for multiple resources.
        Returns aggregated hourly and monthly cost estimates for all specified resources.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CalculatorServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Estimate': grpc.unary_unary_rpc_method_handler(
                    servicer.Estimate,
                    request_deserializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateRequest.FromString,
                    response_serializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateResponse.SerializeToString,
            ),
            'EstimateBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateBatch,
                    request_deserializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchRequest.FromString,
                    response_serializer=nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.billing.v1alpha1.CalculatorService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CalculatorService(object):
    """Calculator service for estimating resource costs.
    """

    @staticmethod
    def Estimate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.billing.v1alpha1.CalculatorService/Estimate',
            nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateRequest.SerializeToString,
            nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.billing.v1alpha1.CalculatorService/EstimateBatch',
            nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchRequest.SerializeToString,
            nebius_dot_billing_dot_v1alpha1_dot_calculator__service__pb2.EstimateBatchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# type: ignore
import logging

import pytest

from nebius.aio import request

request.DEFAULT_AUTH_TIMEOUT = 5.0


@pytest.mark.asyncio
async def test_get_instance() -> None:
    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._interceptor import InterceptedUnaryUnaryCall as UnaryUnaryCall
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel, NoCredentials
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        DiskServiceStub,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            # Return an Instance object as expected by the client
            ret = disk_pb2.Disk()
            ret.metadata.id = request.id
            ret.metadata.name = "MockDisk"
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address, options=[(INSECURE, True)], credentials=NoCredentials()
        )
        stub = DiskServiceStub(channel)

        # Make a request
        req = GetDiskRequest(id="foo-bar")
        call = stub.Get(req)
        assert isinstance(call, UnaryUnaryCall)

        # Await response and metadata
        ret = await call
        assert isinstance(ret, disk_pb2.Disk)
        mdi = await call.initial_metadata()
        mdt = await call.trailing_metadata()
        code = await call.code()
        details = await call.details()

        # Assertions to validate behavior
        assert ret.HasField("metadata")
        assert ret.metadata.id == "foo-bar"
        assert ret.metadata.name == "MockDisk"
        assert code == grpc.StatusCode.OK
        assert details == ""
        assert mdi is not None and len(mdi) == 0
        assert mdt is not None and len(mdt) == 0

    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)


@pytest.mark.asyncio
async def test_get_instance_timeout_change() -> None:
    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._interceptor import InterceptedUnaryUnaryCall as UnaryUnaryCall
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel
    from nebius.aio.token.static import Bearer
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        DiskServiceStub,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            # Return an Instance object as expected by the client
            ret = disk_pb2.Disk()
            ret.metadata.id = request.id
            ret.metadata.name = "MockDisk"
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address, options=[(INSECURE, True)], credentials=Bearer("abc")
        )
        stub = DiskServiceStub(channel)

        # Make a request
        req = GetDiskRequest(id="foo-bar")
        call = stub.Get(req, timeout=1)
        assert isinstance(call, UnaryUnaryCall)

        # Await response and metadata
        ret = await call
        assert isinstance(ret, disk_pb2.Disk)
        mdi = await call.initial_metadata()
        mdt = await call.trailing_metadata()
        code = await call.code()
        details = await call.details()

        # Assertions to validate behavior
        assert ret.HasField("metadata")
        assert ret.metadata.id == "foo-bar"
        assert ret.metadata.name == "MockDisk"
        assert code == grpc.StatusCode.OK
        assert details == ""
        assert mdi is not None and len(mdi) == 0
        assert mdt is not None and len(mdt) == 0

    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)


@pytest.mark.asyncio
async def test_get_error() -> None:
    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._interceptor import InterceptedUnaryUnaryCall as UnaryUnaryCall
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.common.v1.error_pb2 as error_pb2
    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel, NoCredentials
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        DiskServiceStub,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base._service_error import trailing_metadata_of_errors
    from nebius.base.options import INSECURE

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            quota_violation = error_pb2.QuotaFailure.Violation(
                quota="test_quota",
                message="testing quota failure",
                limit="42",
                requested="69",
            )
            quota_failure = error_pb2.QuotaFailure(violations=[quota_violation])
            service_error = error_pb2.ServiceError(
                service="example.service",
                code="test failure",
                quota_failure=quota_failure,
            )

            await context.abort(
                code=grpc.StatusCode.RESOURCE_EXHAUSTED,
                details="test exhausted",
                trailing_metadata=trailing_metadata_of_errors(service_error),
            )

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address, options=[(INSECURE, True)], credentials=NoCredentials()
        )
        stub = DiskServiceStub(channel)

        # Make a request
        req = GetDiskRequest(id="foo-bar")
        call = stub.Get(req)
        assert isinstance(call, UnaryUnaryCall)

        # Await response and metadata
        try:
            mdi = await call.initial_metadata()
            mdt = await call.trailing_metadata()
            code = await call.code()
            details = await call.details()
            ret = await call
            assert isinstance(ret, disk_pb2.Disk)

            # Assertions to validate behavior
            assert ret.metadata.id == "foo-bar"
            assert ret.metadata.name == "MockDisk"
            assert code == grpc.StatusCode.OK
            assert details == ""
            assert mdi is not None and len(mdi) == 0
            assert mdt is not None and len(mdt) == 0
        except Exception as e:
            print(e)

    finally:
        # Clean up
        # if channel is not None:
        #     await channel.close()
        await srv.stop(0)


@pytest.mark.asyncio
async def test_custom_resolver() -> None:
    import grpc
    import grpc.aio

    # Imports needed inside the test function
    from grpc.aio._interceptor import InterceptedUnaryUnaryCall as UnaryUnaryCall
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel, NoCredentials
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        DiskServiceStub,
        add_DiskServiceServicer_to_server,
    )
    from nebius.base.options import INSECURE
    from nebius.base.resolver import Single

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Get(  # noqa: N802 — GRPC method
            self,
            request: GetDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> disk_pb2.Disk:
            assert request.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            # Return an Instance object as expected by the client
            ret = disk_pb2.Disk()
            ret.metadata.id = request.id
            ret.metadata.name = "MockDisk"
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            credentials=NoCredentials(),
            resolver=Single("nebius.compute.v1.DiskService", address),
            options=[(INSECURE, True)],
        )
        stub = DiskServiceStub(channel)

        # Make a request
        req = GetDiskRequest(id="foo-bar")
        call = stub.Get(req)
        assert isinstance(call, UnaryUnaryCall)

        # Await response and metadata
        ret = await call
        assert isinstance(ret, disk_pb2.Disk)
        mdi = await call.initial_metadata()
        mdt = await call.trailing_metadata()
        code = await call.code()
        details = await call.details()

        # Assertions to validate behavior
        assert ret.metadata.id == "foo-bar"
        assert ret.metadata.name == "MockDisk"
        assert code == grpc.StatusCode.OK
        assert details == ""
        assert mdi is not None and len(mdi) == 0
        assert mdt is not None and len(mdt) == 0

    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bnebius/vpc/v1/network.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\"\xaf\x01\n\x07Network\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12.\n\x04spec\x18\x02 \x01(\x0b\x32\x1a.nebius.vpc.v1.NetworkSpecR\x04spec\x12\x34\n\x06status\x18\x03 \x01(\x0b\x32\x1c.nebius.vpc.v1.NetworkStatusR\x06status\"\xc2\x01\n\x0bNetworkSpec\x12Z\n\x12ipv4_private_pools\x18\x01 \x01(\x0b\x32&.nebius.vpc.v1.IPv4PrivateNetworkPoolsB\x04\xbaJ\x01\x07R\x10ipv4PrivatePools\x12W\n\x11ipv4_public_pools\x18\x02 \x01(\x0b\x32%.nebius.vpc.v1.IPv4PublicNetworkPoolsB\x04\xbaJ\x01\x07R\x0fipv4PublicPools\"K\n\x17IPv4PrivateNetworkPools\x12\x30\n\x05pools\x18\x01 \x03(\x0b\x32\x1a.nebius.vpc.v1.NetworkPoolR\x05pools\"J\n\x16IPv4PublicNetworkPools\x12\x30\n\x05pools\x18\x01 \x03(\x0b\x32\x1a.nebius.vpc.v1.NetworkPoolR\x05pools\"%\n\x0bNetworkPool\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xc5\x01\n\rNetworkStatus\x12\x38\n\x05state\x18\x01 \x01(\x0e\x32\".nebius.vpc.v1.NetworkStatus.StateR\x05state\x12\x33\n\x16\x64\x65\x66\x61ult_route_table_id\x18\x05 \x01(\tR\x13\x64\x65\x66\x61ultRouteTableId\"E\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42S\n\x14\x61i.nebius.pub.vpc.v1B\x0cNetworkProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.network_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\014NetworkProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _NETWORKSPEC.fields_by_name['ipv4_private_pools']._options = None
  _NETWORKSPEC.fields_by_name['ipv4_private_pools']._serialized_options = b'\272J\001\007'
  _NETWORKSPEC.fields_by_name['ipv4_public_pools']._options = None
  _NETWORKSPEC.fields_by_name['ipv4_public_pools']._serialized_options = b'\272J\001\007'
  _NETWORKPOOL.fields_by_name['id']._options = None
  _NETWORKPOOL.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_NETWORK']._serialized_start=135
  _globals['_NETWORK']._serialized_end=310
  _globals['_NETWORKSPEC']._serialized_start=313
  _globals['_NETWORKSPEC']._serialized_end=507
  _globals['_IPV4PRIVATENETWORKPOOLS']._serialized_start=509
  _globals['_IPV4PRIVATENETWORKPOOLS']._serialized_end=584
  _globals['_IPV4PUBLICNETWORKPOOLS']._serialized_start=586
  _globals['_IPV4PUBLICNETWORKPOOLS']._serialized_end=660
  _globals['_NETWORKPOOL']._serialized_start=662
  _globals['_NETWORKPOOL']._serialized_end=699
  _globals['_NETWORKSTATUS']._serialized_start=702
  _globals['_NETWORKSTATUS']._serialized_end=899
  _globals['_NETWORKSTATUS_STATE']._serialized_start=830
  _globals['_NETWORKSTATUS_STATE']._serialized_end=899
# @@protoc_insertion_point(module_scope)



from typing import Any, final


class Singleton(type):
    """A metaclass that creates a singleton class."""

    _instances = dict[Any, Any]()

    def __call__(cls, *args: Any, **kwargs: Any) -> Any:
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


@final
class UnsetType(metaclass=Singleton):
    """Used to represent an unset optional parameter."""

    def __repr__(self) -> str:
        return __name__ + ".Unset"


Unset = UnsetType()
"""Used to represent an unset optional parameter."""



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1alpha1/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_service_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1alpha1 import image_pb2 as nebius_dot_compute_dot_v1alpha1_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+nebius/compute/v1alpha1/image_service.proto\x12\x17nebius.compute.v1alpha1\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a.nebius/common/v1alpha1/operation_service.proto\x1a#nebius/compute/v1alpha1/image.proto\"!\n\x0fGetImageRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"_\n\x1dGetImageLatestByFamilyRequest\x12!\n\x0cimage_family\x18\x01 \x01(\tR\x0bimageFamily\x12\x1b\n\tparent_id\x18\x02 \x01(\tR\x08parentId\"\xd6\x01\n\x11ListImagesRequest\x12\x1b\n\tparent_id\x18\x01 \x01(\tR\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12h\n\x06\x66ilter\x18\x04 \x01(\tBP\x18\x01\xd2JK\n\n2025-06-16\x12=it is not implemented, filtering could be done on client sideR\x06\x66ilter\"r\n\x12ListImagesResponse\x12\x34\n\x05items\x18\x01 \x03(\x0b\x32\x1e.nebius.compute.v1alpha1.ImageR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\x8e\x04\n\x0cImageService\x12O\n\x03Get\x12(.nebius.compute.v1alpha1.GetImageRequest\x1a\x1e.nebius.compute.v1alpha1.Image\x12O\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x1e.nebius.compute.v1alpha1.Image\x12k\n\x11GetLatestByFamily\x12\x36.nebius.compute.v1alpha1.GetImageLatestByFamilyRequest\x1a\x1e.nebius.compute.v1alpha1.Image\x12_\n\x04List\x12*.nebius.compute.v1alpha1.ListImagesRequest\x1a+.nebius.compute.v1alpha1.ListImagesResponse\x12\x7f\n\x16ListOperationsByParent\x12\x35.nebius.common.v1alpha1.ListOperationsByParentRequest\x1a..nebius.common.v1alpha1.ListOperationsResponse\x1a\r\x88\x02\x01\xbaJ\x07\x63omputeBo\n\x1e\x61i.nebius.pub.compute.v1alpha1B\x11ImageServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\xb8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1alpha1.image_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.compute.v1alpha1B\021ImageServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/compute/v1alpha1\270\001\001'
  _LISTIMAGESREQUEST.fields_by_name['filter']._options = None
  _LISTIMAGESREQUEST.fields_by_name['filter']._serialized_options = b'\030\001\322JK\n\n2025-06-16\022=it is not implemented, filtering could be done on client side'
  _IMAGESERVICE._options = None
  _IMAGESERVICE._serialized_options = b'\210\002\001\272J\007compute'
  _globals['_GETIMAGEREQUEST']._serialized_start=216
  _globals['_GETIMAGEREQUEST']._serialized_end=249
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_start=251
  _globals['_GETIMAGELATESTBYFAMILYREQUEST']._serialized_end=346
  _globals['_LISTIMAGESREQUEST']._serialized_start=349
  _globals['_LISTIMAGESREQUEST']._serialized_end=563
  _globals['_LISTIMAGESRESPONSE']._serialized_start=565
  _globals['_LISTIMAGESRESPONSE']._serialized_end=679
  _globals['_IMAGESERVICE']._serialized_start=682
  _globals['_IMAGESERVICE']._serialized_end=1208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/disk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cnebius/compute/v1/disk.proto\x12\x11nebius.compute.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xae\x01\n\x04\x44isk\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12/\n\x04spec\x18\x02 \x01(\x0b\x32\x1b.nebius.compute.v1.DiskSpecR\x04spec\x12\x35\n\x06status\x18\x03 \x01(\x0b\x32\x1d.nebius.compute.v1.DiskStatusR\x06status\"\x97\x05\n\x08\x44iskSpec\x12\x1f\n\nsize_bytes\x18\x01 \x01(\x03H\x00R\tsizeBytes\x12\'\n\x0esize_kibibytes\x18\x02 \x01(\x03H\x00R\rsizeKibibytes\x12\'\n\x0esize_mebibytes\x18\x03 \x01(\x03H\x00R\rsizeMebibytes\x12\'\n\x0esize_gibibytes\x18\x04 \x01(\x03H\x00R\rsizeGibibytes\x12.\n\x10\x62lock_size_bytes\x18\x05 \x01(\x03\x42\x04\xbaJ\x01\x02R\x0e\x62lockSizeBytes\x12\x44\n\x04type\x18\x06 \x01(\x0e\x32$.nebius.compute.v1.DiskSpec.DiskTypeB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x04type\x12.\n\x0fsource_image_id\x18\x08 \x01(\tB\x04\xbaJ\x01\x02H\x01R\rsourceImageId\x12\\\n\x13source_image_family\x18\n \x01(\x0b\x32$.nebius.compute.v1.SourceImageFamilyB\x04\xbaJ\x01\x02H\x01R\x11sourceImageFamily\x12P\n\x0f\x64isk_encryption\x18\x0b \x01(\x0b\x32!.nebius.compute.v1.DiskEncryptionB\x04\xbaJ\x01\x02R\x0e\x64iskEncryption\"t\n\x08\x44iskType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0f\n\x0bNETWORK_SSD\x10\x01\x12\x0f\n\x0bNETWORK_HDD\x10\x02\x12\x1e\n\x1aNETWORK_SSD_NON_REPLICATED\x10\x03\x12\x15\n\x11NETWORK_SSD_IO_M3\x10\x04\x42\r\n\x04size\x12\x05\xbaH\x02\x08\x01\x42\x08\n\x06sourceJ\x04\x08\x07\x10\x08J\x04\x08\t\x10\n\"[\n\x11SourceImageFamily\x12)\n\x0cimage_family\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0bimageFamily\x12\x1b\n\tparent_id\x18\x02 \x01(\tR\x08parentId\"\xa8\x05\n\nDiskStatus\x12\x39\n\x05state\x18\x01 \x01(\x0e\x32#.nebius.compute.v1.DiskStatus.StateR\x05state\x12+\n\x11state_description\x18\x02 \x01(\tR\x10stateDescription\x12\x32\n\x15read_write_attachment\x18\x03 \x01(\tR\x13readWriteAttachment\x12\x32\n\x15read_only_attachments\x18\x04 \x03(\tR\x13readOnlyAttachments\x12&\n\x0fsource_image_id\x18\x05 \x01(\tR\rsourceImageId\x12\x1d\n\nsize_bytes\x18\x06 \x01(\x03R\tsizeBytes\x12 \n\x0breconciling\x18\x07 \x01(\x08R\x0breconciling\x12(\n\x10\x62lock_size_bytes\x18\x08 \x01(\x03R\x0e\x62lockSizeBytes\x12{\n\x1dsource_image_cpu_architecture\x18\t \x01(\x0e\x32\x38.nebius.compute.v1.DiskStatus.SourceImageCPUArchitectureR\x1asourceImageCpuArchitecture\"d\n\x05State\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\t\n\x05READY\x10\x02\x12\x0c\n\x08UPDATING\x10\x03\x12\x0c\n\x08\x44\x45LETING\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\n\n\x06\x42ROKEN\x10\x06\"T\n\x1aSourceImageCPUArchitecture\x12 \n\x1cSOURCE_IMAGE_CPU_UNSPECIFIED\x10\x00\x12\t\n\x05\x41MD64\x10\x01\x12\t\n\x05\x41RM64\x10\x02\"\xae\x01\n\x0e\x44iskEncryption\x12H\n\x04type\x18\x01 \x01(\x0e\x32\x34.nebius.compute.v1.DiskEncryption.DiskEncryptionTypeR\x04type\"R\n\x12\x44iskEncryptionType\x12\x1f\n\x1b\x44ISK_ENCRYPTION_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x44ISK_ENCRYPTION_MANAGED\x10\x01\x42X\n\x18\x61i.nebius.pub.compute.v1B\tDiskProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.disk_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\tDiskProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _DISKSPEC.oneofs_by_name['size']._options = None
  _DISKSPEC.oneofs_by_name['size']._serialized_options = b'\272H\002\010\001'
  _DISKSPEC.fields_by_name['block_size_bytes']._options = None
  _DISKSPEC.fields_by_name['block_size_bytes']._serialized_options = b'\272J\001\002'
  _DISKSPEC.fields_by_name['type']._options = None
  _DISKSPEC.fields_by_name['type']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _DISKSPEC.fields_by_name['source_image_id']._options = None
  _DISKSPEC.fields_by_name['source_image_id']._serialized_options = b'\272J\001\002'
  _DISKSPEC.fields_by_name['source_image_family']._options = None
  _DISKSPEC.fields_by_name['source_image_family']._serialized_options = b'\272J\001\002'
  _DISKSPEC.fields_by_name['disk_encryption']._options = None
  _DISKSPEC.fields_by_name['disk_encryption']._serialized_options = b'\272J\001\002'
  _SOURCEIMAGEFAMILY.fields_by_name['image_family']._options = None
  _SOURCEIMAGEFAMILY.fields_by_name['image_family']._serialized_options = b'\272H\003\310\001\001'
  _globals['_DISK']._serialized_start=140
  _globals['_DISK']._serialized_end=314
  _globals['_DISKSPEC']._serialized_start=317
  _globals['_DISKSPEC']._serialized_end=980
  _globals['_DISKSPEC_DISKTYPE']._serialized_start=827
  _globals['_DISKSPEC_DISKTYPE']._serialized_end=943
  _globals['_SOURCEIMAGEFAMILY']._serialized_start=982
  _globals['_SOURCEIMAGEFAMILY']._serialized_end=1073
  _globals['_DISKSTATUS']._serialized_start=1076
  _globals['_DISKSTATUS']._serialized_end=1756
  _globals['_DISKSTATUS_STATE']._serialized_start=1570
  _globals['_DISKSTATUS_STATE']._serialized_end=1670
  _globals['_DISKSTATUS_SOURCEIMAGECPUARCHITECTURE']._serialized_start=1672
  _globals['_DISKSTATUS_SOURCEIMAGECPUARCHITECTURE']._serialized_end=1756
  _globals['_DISKENCRYPTION']._serialized_start=1759
  _globals['_DISKENCRYPTION']._serialized_end=1933
  _globals['_DISKENCRYPTION_DISKENCRYPTIONTYPE']._serialized_start=1851
  _globals['_DISKENCRYPTION_DISKENCRYPTIONTYPE']._serialized_end=1933
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/static_key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.iam.v1 import access_pb2 as nebius_dot_iam_dot_v1_dot_access__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1enebius/iam/v1/static_key.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x1anebius/iam/v1/access.proto\"\xcb\x01\n\tStaticKey\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x38\n\x04spec\x18\x02 \x01(\x0b\x32\x1c.nebius.iam.v1.StaticKeySpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12<\n\x06status\x18\x03 \x01(\x0b\x32\x1e.nebius.iam.v1.StaticKeyStatusB\x04\xbaJ\x01\x05R\x06status\"\xba\x02\n\rStaticKeySpec\x12\x36\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x16.nebius.iam.v1.AccountB\x04\xbaJ\x01\x02R\x07\x61\x63\x63ount\x12L\n\x07service\x18\x02 \x01(\x0e\x32*.nebius.iam.v1.StaticKeySpec.ClientServiceB\x06\xbaH\x03\xc8\x01\x01R\x07service\x12\x38\n\texpiresAt\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\"i\n\rClientService\x12\x1e\n\x1a\x43LIENT_SERVICE_UNSPECIFIED\x10\x00\x12\x11\n\rOBSERVABILITY\x10\x01\x12\x16\n\x12\x43ONTAINER_REGISTRY\x10\x02\x12\r\n\tAI_STUDIO\x10\x03\")\n\x0fStaticKeyStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tiveBU\n\x14\x61i.nebius.pub.iam.v1B\x0eStaticKeyProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.static_key_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\016StaticKeyProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _STATICKEY.fields_by_name['metadata']._options = None
  _STATICKEY.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _STATICKEY.fields_by_name['spec']._options = None
  _STATICKEY.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _STATICKEY.fields_by_name['status']._options = None
  _STATICKEY.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _STATICKEYSPEC.fields_by_name['account']._options = None
  _STATICKEYSPEC.fields_by_name['account']._serialized_options = b'\272J\001\002'
  _STATICKEYSPEC.fields_by_name['service']._options = None
  _STATICKEYSPEC.fields_by_name['service']._serialized_options = b'\272H\003\310\001\001'
  _globals['_STATICKEY']._serialized_start=199
  _globals['_STATICKEY']._serialized_end=402
  _globals['_STATICKEYSPEC']._serialized_start=405
  _globals['_STATICKEYSPEC']._serialized_end=719
  _globals['_STATICKEYSPEC_CLIENTSERVICE']._serialized_start=614
  _globals['_STATICKEYSPEC_CLIENTSERVICE']._serialized_end=719
  _globals['_STATICKEYSTATUS']._serialized_start=721
  _globals['_STATICKEYSTATUS']._serialized_end=762
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.common.v1 import operation_service_pb2 as nebius_dot_common_dot_v1_dot_operation__service__pb2
from nebius.api.nebius.compute.v1 import instance_pb2 as nebius_dot_compute_dot_v1_dot_instance__pb2
from nebius.api.nebius.compute.v1 import instance_service_pb2 as nebius_dot_compute_dot_v1_dot_instance__service__pb2
from nebius.api.nebius.compute.v1 import operation_service_pb2 as nebius_dot_compute_dot_v1_dot_operation__service__pb2


class InstanceServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Get',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/GetByName',
                request_serializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/List',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
                response_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Create',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Update',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Delete',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Start',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Stop = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/Stop',
                request_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperationsByParent = channel.unary_unary(
                '/nebius.compute.v1.InstanceService/ListOperationsByParent',
                request_serializer=nebius_dot_compute_dot_v1_dot_operation__service__pb2.ListOperationsByParentRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__service__pb2.ListOperationsResponse.FromString,
                )


class InstanceServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Retrieves detailed information about a specific VM instance by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Retrieves detailed information about a specific VM instance by its parent and name.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists all VM instances within a specified parent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a new VM instance based on the provided specification.
        For details, see https://docs.nebius.com/compute/virtual-machines/manage
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates an existing VM instance with new configuration parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes a VM instance by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts a stopped VM instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops a running VM instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperationsByParent(self, request, context):
        """Lists all operations that were performed within a specific parent resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.FromString,
                    response_serializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperationsByParent': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperationsByParent,
                    request_deserializer=nebius_dot_compute_dot_v1_dot_operation__service__pb2.ListOperationsByParentRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__service__pb2.ListOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.compute.v1.InstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstanceService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Get',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
            nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/GetByName',
            nebius_dot_common_dot_v1_dot_metadata__pb2.GetByNameRequest.SerializeToString,
            nebius_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/List',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Create',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Update',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Delete',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Start',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/Stop',
            nebius_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperationsByParent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.compute.v1.InstanceService/ListOperationsByParent',
            nebius_dot_compute_dot_v1_dot_operation__service__pb2.ListOperationsByParentRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__service__pb2.ListOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/quotas/v1/quota_allowance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.quotas.v1 import quota_allowance_pb2 as nebius_dot_quotas_dot_v1_dot_quota__allowance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.nebius/quotas/v1/quota_allowance_service.proto\x12\x10nebius.quotas.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a&nebius/quotas/v1/quota_allowance.proto\"}\n\x1aListQuotaAllowancesRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"6\n\x18GetQuotaAllowanceRequest\x12\x1a\n\x02id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x03R\x02id\"}\n\x1bListQuotaAllowancesResponse\x12\x36\n\x05items\x18\x01 \x03(\x0b\x32 .nebius.quotas.v1.QuotaAllowanceR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"s\n\x10GetByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\x12\x1e\n\x06region\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x06region2\xc5\x02\n\x15QuotaAllowanceService\x12\x63\n\x04List\x12,.nebius.quotas.v1.ListQuotaAllowancesRequest\x1a-.nebius.quotas.v1.ListQuotaAllowancesResponse\x12S\n\x03Get\x12*.nebius.quotas.v1.GetQuotaAllowanceRequest\x1a .nebius.quotas.v1.QuotaAllowance\x12Q\n\tGetByName\x12\".nebius.quotas.v1.GetByNameRequest\x1a .nebius.quotas.v1.QuotaAllowance\x1a\x1f\xbaJ\x1cquota-dispatcher.billing-cplBg\n\x17\x61i.nebius.pub.quotas.v1B\x1aQuotaAllowanceServiceProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/quotas/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.quotas.v1.quota_allowance_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.quotas.v1B\032QuotaAllowanceServiceProtoP\001Z.github.com/nebius/gosdk/proto/nebius/quotas/v1'
  _LISTQUOTAALLOWANCESREQUEST.fields_by_name['parent_id']._options = None
  _LISTQUOTAALLOWANCESREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETQUOTAALLOWANCEREQUEST.fields_by_name['id']._options = None
  _GETQUOTAALLOWANCEREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001\272J\001\003'
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _GETBYNAMEREQUEST.fields_by_name['region']._options = None
  _GETBYNAMEREQUEST.fields_by_name['region']._serialized_options = b'\272H\003\310\001\001'
  _QUOTAALLOWANCESERVICE._options = None
  _QUOTAALLOWANCESERVICE._serialized_options = b'\272J\034quota-dispatcher.billing-cpl'
  _globals['_LISTQUOTAALLOWANCESREQUEST']._serialized_start=163
  _globals['_LISTQUOTAALLOWANCESREQUEST']._serialized_end=288
  _globals['_GETQUOTAALLOWANCEREQUEST']._serialized_start=290
  _globals['_GETQUOTAALLOWANCEREQUEST']._serialized_end=344
  _globals['_LISTQUOTAALLOWANCESRESPONSE']._serialized_start=346
  _globals['_LISTQUOTAALLOWANCESRESPONSE']._serialized_end=471
  _globals['_GETBYNAMEREQUEST']._serialized_start=473
  _globals['_GETBYNAMEREQUEST']._serialized_end=588
  _globals['_QUOTAALLOWANCESERVICE']._serialized_start=591
  _globals['_QUOTAALLOWANCESERVICE']._serialized_end=916
# @@protoc_insertion_point(module_scope)



import argparse
from time import time  # type: ignore[unused-ignore]

from nebius.aio.service_error import RequestError
from nebius.api.nebius.common.v1 import ResourceMetadata
from nebius.api.nebius.storage.v1 import (
    BucketServiceClient,
    BucketSpec,
    CreateBucketRequest,
    DeleteBucketRequest,
    GetBucketRequest,
    VersioningPolicy,
)
from nebius.sdk import SDK

if __name__ == "__main__":
    import logging

    logging.basicConfig(level=logging.DEBUG)

    async def main() -> None:
        parser = argparse.ArgumentParser(
            "examples/basic.py",
            description="basic example that creates and then deletes a bucket",
        )
        parser.add_argument("--domain", help="domain override", default=None)
        parser.add_argument(
            "project_id", help="project in which to create and delete a test bucket"
        )
        args = parser.parse_args()

        sdk = SDK(domain=args.domain)
        print(await sdk.whoami())

        project_id: str = args.project_id

        service = BucketServiceClient(sdk)
        try:
            req = service.create(
                CreateBucketRequest(
                    metadata=ResourceMetadata(
                        parent_id=project_id,
                        name=f"test-pysdk-bucket-{time()}",
                    ),
                    spec=BucketSpec(
                        versioning_policy=VersioningPolicy.DISABLED,
                        max_size_bytes=4096,
                    ),
                )
            )
            ret = await req
            mdi = await req.initial_metadata()
            mdt = await req.trailing_metadata()
            status = await req.status()
            # or just do `ret: Operation = await service.Create(req)`
            print(ret)
            print(mdi, mdt, status)
            await ret.wait()
            print(ret)
            bucket = await service.get(GetBucketRequest(id=ret.resource_id))
            print(bucket)
            await service.delete(DeleteBucketRequest(id=bucket.metadata.id))
        except RequestError as e:
            print(e)
            raise

    import asyncio

    asyncio.run(main())
